netapp_ontap.resources.shelf API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.shelf`

Copyright © 2020 NetApp Inc. All rights reserved.

## Retrieving storage shelf information

The storage shelf GET API retrieves all of the shelves in the cluster.

## Examples

### 1) Retrieve a list of shelves from the cluster

#### The following example shows the response with a list of shelves in the cluster:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Shelf

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Shelf.get_collection()))

Try it out

    [
        Shelf({"uid": "3109174803597886800"}),
        Shelf({"uid": "9237728366621690448"}),
        Shelf({"uid": "9946762738829886800"}),
        Shelf({"uid": "10318311901725526608"}),
        Shelf({"uid": "13477584846688355664"}),
    ]

### 2) Retrieve a specific shelf from the cluster

#### The following example shows the response of the requested shelf. If there is no shelf with the requested uid, an error is returned.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Shelf

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Shelf(uid=3109174803597886800)
        resource.get()
        print(resource)

Try it out

    Shelf(
        {
            "id": "10",
            "module_type": "iom6",
            "internal": False,
            "paths": [
                {
                    "node": {
                        "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                        "name": "node-1",
                        "_links": {
                            "self": {
                                "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                            }
                        },
                    },
                    "name": "0e",
                },
                {
                    "node": {
                        "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                        "name": "node-1",
                        "_links": {
                            "self": {
                                "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                            }
                        },
                    },
                    "name": "0g",
                },
            ],
            "ports": [
                {
                    "id": 0,
                    "remote": {"phy": "08", "wwn": "5001086000702488"},
                    "cable": {
                        "identifier": "5001086000702488-500a098000c9edbf",
                        "serial_number": "APF16510229807",
                        "length": "2m",
                        "part_number": "112-00430+A0",
                    },
                    "state": "connected",
                    "wwn": "500A098000C9EDBF",
                    "module_id": "a",
                    "designator": "square",
                    "internal": False,
                },
                {
                    "id": 1,
                    "remote": {"phy": "00", "wwn": "500A098000D5C4BF"},
                    "cable": {
                        "identifier": "500a098000d5c4bf-500a098000c9edbf",
                        "serial_number": "APF133917610YT",
                        "length": "0.5-1.0m",
                        "part_number": "112-00176+A0",
                    },
                    "state": "connected",
                    "wwn": "500A098000C9EDBF",
                    "module_id": "a",
                    "designator": "circle",
                    "internal": False,
                },
                {
                    "id": 2,
                    "remote": {"phy": "08", "wwn": "5001086000702648"},
                    "cable": {
                        "identifier": "5001086000702648-500a098004f208bf",
                        "serial_number": "APF16510229540",
                        "length": "2m",
                        "part_number": "112-00430+A0",
                    },
                    "state": "connected",
                    "wwn": "500A098004F208BF",
                    "module_id": "b",
                    "designator": "square",
                    "internal": False,
                },
                {
                    "id": 3,
                    "remote": {"phy": "00", "wwn": "500A0980062BA33F"},
                    "cable": {
                        "identifier": "500a0980062ba33f-500a098004f208bf",
                        "serial_number": "832210017",
                        "length": "0.5-1.0m",
                        "part_number": "112-00176+20",
                    },
                    "state": "connected",
                    "wwn": "500A098004F208BF",
                    "module_id": "b",
                    "designator": "circle",
                    "internal": False,
                },
            ],
            "serial_number": "SHU0954292N0HAH",
            "connection_type": "sas",
            "local": True,
            "state": "ok",
            "model": "DS4246",
            "name": "6.10",
            "uid": "3109174803597886800",
            "bays": [
                {"id": 0, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 1, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 2, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 3, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 4, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 5, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 6, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 7, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 8, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 9, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 10, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 11, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 12, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 13, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 14, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 15, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 16, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 17, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 18, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 19, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 20, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 21, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 22, "state": "ok", "has_disk": True, "type": "single_disk"},
                {"id": 23, "state": "ok", "has_disk": True, "type": "single_disk"},
            ],
            "frus": [
                {
                    "type": "module",
                    "id": 0,
                    "firmware_version": "0191",
                    "serial_number": "8001900099",
                    "part_number": "111-00690+B2",
                    "state": "ok",
                },
                {
                    "type": "module",
                    "id": 1,
                    "firmware_version": "0191",
                    "serial_number": "7903785183",
                    "part_number": "111-00190+B0",
                    "state": "ok",
                },
                {
                    "type": "psu",
                    "id": 1,
                    "firmware_version": "0311",
                    "serial_number": "PMW82562007513E",
                    "part_number": "0082562-12",
                    "state": "ok",
                },
                {
                    "type": "psu",
                    "id": 2,
                    "firmware_version": "0311",
                    "serial_number": "PMW825620075138",
                    "part_number": "0082562-12",
                    "state": "ok",
                },
                {
                    "type": "psu",
                    "id": 3,
                    "firmware_version": "0311",
                    "serial_number": "PMW8256200750BA",
                    "part_number": "0082562-12",
                    "state": "ok",
                },
                {
                    "type": "psu",
                    "id": 4,
                    "firmware_version": "0311",
                    "serial_number": "PMW8256200750A2",
                    "part_number": "0082562-12",
                    "state": "ok",
                },
            ],
            "disk_count": 24,
        }
    )

## Classes

`class Shelf (*args, **kwargs)`

  Allows interaction with Shelf objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of shelves.

    ### Related ONTAP commands

    - `storage shelf show`
    - `storage shelf port show`
    - `storage shelf drawer show`

    ### Learn more

    - `DOC /storage/shelves`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of shelves.

    ### Related ONTAP commands

    - `storage shelf show`
    - `storage shelf port show`
    - `storage shelf drawer show`

    ### Learn more

    - `DOC /storage/shelves`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of shelves.

    ### Related ONTAP commands

    - `storage shelf show`
    - `storage shelf port show`
    - `storage shelf drawer show`

    ### Learn more

    - `DOC /storage/shelves`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a specific shelf.

    ### Related ONTAP commands

    - `storage shelf show`
    - `storage shelf port show`
    - `storage shelf drawer show`

    ### Learn more

    - `DOC /storage/shelves`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ShelfSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Shelf object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `bays GET`

    The bays field of the shelf.

  `connection_type GET`

    The connection_type field of the shelf.

    Valid choices:

    - unknown
    - fc
    - sas
    - nvme
  `disk_count GET`

    The disk_count field of the shelf.

    Example: 12

  `drawers GET`

    The drawers field of the shelf.

  `frus GET`

    The frus field of the shelf.

  `id GET`

    The id field of the shelf.

    Example: 1

  `internal GET`

    The internal field of the shelf.

  `local GET`

    The local field of the shelf.

  `model GET`

    The model field of the shelf.

    Example: DS2246

  `module_type GET`

    The module_type field of the shelf.

    Valid choices:

    - unknown
    - iom6
    - iom6e
    - iom12
    - iom12e
    - iom12f
    - nsm100
    - psm3e
  `name GET`

    The name field of the shelf.

    Example: 1.1

  `paths GET`

    The paths field of the shelf.

  `ports GET`

    The ports field of the shelf.

  `serial_number GET`

    The serial_number field of the shelf.

    Example: SHFMS1514000895

  `state GET`

    The state field of the shelf.

    Valid choices:

    - unknown
    - ok
    - error
  `uid GET`

    The uid field of the shelf.

    Example: 7777841915827391056

  `vendor GET`

    The vendor field of the shelf.